pub enum Type {
Uninit,
Foreground,
Background,
}Expand description
Enumeration of the task / thread types.
Since we have a well-defined primitives of creating tasks of different kind and using async / await language to control them, for convenience, each task must only be associated with one type, and each thread is only allowed to execute one type of task, so there’s no ambiguity while querying the type.
Variants