ThreadingMode

Enum ThreadingMode 

pub enum ThreadingMode {
    Disjoint,
    Contended,
}
Currently initialized threading mode.

Variants



Disjoint

Disjoint mode is the ideal mode that multiple CPUs are available, and thus foreground thread and background threads may run on disjoint set of CPUs.

This is the mode set whenever there’re 2 or more CPUs permitted.



Contended

Contended mode is the downgrade mode that only single CPU is available, and foreground thread and background threads have to run on that CPU.

This mode is set when there’s single CPU or we are unable to get permitted CPU set.