Framework

Struct Framework 

pub struct Framework { /* private fields */ }
Initialized framework handle.

This handle is used to control the lifecycle of the whole system. By dropping it, you dispose the entire framework.

Disposing the framework is required on some platform such as windows.

Implementations

Source

impl Framework

pub fn status(&self) -> &Status