ReadyPoll

Struct ReadyPoll 

pub struct ReadyPoll { /* private fields */ }
Ready poller object.

This is the tester side result of the ready poll, providing ready() method to check if the wrapped future is ready.

Implementations

Source

impl ReadyPoll

pub fn ready(&self) -> bool