pub fn drain_foreground_loopback()Expand description
Drains the foreground tasks dispatched from background threads and push them to the task queue of foreground thread.
This function must be called from the foreground thread. It’s non-blocking, which means it returns immediately after pushing the tasks.