Manipulation of the task framework itself.
Normally the task module user does not need to care about manipulating the task framework, so we move it to a submodule to avoid overwhelming them.
Structs
- Config
- Configuration for the task framework.
- Framework
- Initialized framework handle.
- Status
- Task framework initialization status.
Enums
- Threading
Mode - Currently initialized threading mode.
Functions
- initialize
- Initialize the task framework.