Handle

Trait Handle 

pub trait Handle<T>: Future<Output = T>
where T: 'static,
{ // Required method fn detach(self); }
Task handle trait.

This handle is used to receive result from the task, as well as controlling the task like cancelling and detaching it:

  • Awaiting this handle receives the result.
  • Dropping this handle cancels the task.
  • Calling detach consumes and detaches the task.

Required Methods

fn detach(self)

Implementors